@@ -25,12 +25,12 @@ import (
 	"syscall"
 	"text/template"
 
-	"github.com/containerd/containerd/v2/pkg/oci"
+	"github.com/containerd/containerd/oci"
 	"github.com/opencontainers/runtime-spec/specs-go"
-	"github.com/urfave/cli/v2"
+	"github.com/urfave/cli"
 )
 
-var ociHook = &cli.Command{
+var ociHook = cli.Command{
 	Name:  "oci-hook",
 	Usage: "Provides a base for OCI runtime hooks to allow arguments to be injected.",
 	Action: func(context *cli.Context) error {
@@ -45,7 +45,7 @@ var ociHook = &cli.Command{
 		}
 		var (
 			ctx  = newTemplateContext(state, spec)
-			args = context.Args().Slice()
+			args = []string(context.Args())
 			env  = os.Environ()
 		)
 		if err := newList(&args).render(ctx); err != nil {
