@@ -27,20 +27,21 @@ import (
 	"text/tabwriter"
 	"time"
 
-	"github.com/containerd/containerd/v2/cmd/ctr/commands"
-	"github.com/containerd/containerd/v2/core/content"
-	"github.com/containerd/containerd/v2/core/remotes"
-	"github.com/containerd/errdefs"
 	"github.com/containerd/log"
 	units "github.com/docker/go-units"
 	digest "github.com/opencontainers/go-digest"
 	ocispec "github.com/opencontainers/image-spec/specs-go/v1"
-	"github.com/urfave/cli/v2"
+	"github.com/urfave/cli"
+
+	"github.com/containerd/containerd/cmd/ctr/commands"
+	"github.com/containerd/containerd/content"
+	"github.com/containerd/containerd/errdefs"
+	"github.com/containerd/containerd/remotes"
 )
 
 var (
 	// Command is the cli command for managing content
-	Command = &cli.Command{
+	Command = cli.Command{
 		Name:  "content",
 		Usage: "Manage content",
 		Subcommands: cli.Commands{
@@ -59,7 +60,7 @@ var (
 		},
 	}
 
-	getCommand = &cli.Command{
+	getCommand = cli.Command{
 		Name:        "get",
 		Usage:       "Get the data for an object",
 		ArgsUsage:   "[<digest>, ...]",
@@ -88,17 +89,17 @@ var (
 		},
 	}
 
-	ingestCommand = &cli.Command{
+	ingestCommand = cli.Command{
 		Name:        "ingest",
 		Usage:       "Accept content into the store",
 		ArgsUsage:   "[flags] <key>",
 		Description: "ingest objects into the local content store",
 		Flags: []cli.Flag{
-			&cli.Int64Flag{
+			cli.Int64Flag{
 				Name:  "expected-size",
 				Usage: "Validate against provided size",
 			},
-			&cli.StringFlag{
+			cli.StringFlag{
 				Name:  "expected-digest",
 				Usage: "Verify content against expected digest",
 			},
@@ -130,19 +131,18 @@ var (
 		},
 	}
 
-	activeIngestCommand = &cli.Command{
+	activeIngestCommand = cli.Command{
 		Name:        "active",
 		Usage:       "Display active transfers",
 		ArgsUsage:   "[flags] [<regexp>]",
 		Description: "display the ongoing transfers",
 		Flags: []cli.Flag{
-			&cli.DurationFlag{
-				Name:    "timeout",
-				Aliases: []string{"t"},
-				Usage:   "Total timeout for fetch",
-				EnvVars: []string{"CONTAINERD_FETCH_TIMEOUT"},
+			cli.DurationFlag{
+				Name:   "timeout, t",
+				Usage:  "Total timeout for fetch",
+				EnvVar: "CONTAINERD_FETCH_TIMEOUT",
 			},
-			&cli.StringFlag{
+			cli.StringFlag{
 				Name:  "root",
 				Usage: "Path to content store root",
 				Value: "/tmp/content", // TODO(stevvooe): for now, just use the PWD/.content
@@ -173,23 +173,22 @@ var (
 		},
 	}
 
-	listCommand = &cli.Command{
+	listCommand = cli.Command{
 		Name:        "list",
 		Aliases:     []string{"ls"},
 		Usage:       "List all blobs in the store",
 		ArgsUsage:   "[flags]",
 		Description: "list blobs in the content store",
 		Flags: []cli.Flag{
-			&cli.BoolFlag{
-				Name:    "quiet",
-				Aliases: []string{"q"},
-				Usage:   "Print only the blob digest",
+			cli.BoolFlag{
+				Name:  "quiet, q",
+				Usage: "Print only the blob digest",
 			},
 		},
 		Action: func(context *cli.Context) error {
 			var (
 				quiet = context.Bool("quiet")
-				args  = context.Args().Slice()
+				args  = []string(context.Args())
 			)
 			client, ctx, cancel, err := commands.NewClient(context)
 			if err != nil {
@@ -234,7 +233,7 @@ var (
 		},
 	}
 
-	setLabelsCommand = &cli.Command{
+	setLabelsCommand = cli.Command{
 		Name:        "label",
 		Usage:       "Add labels to content",
 		ArgsUsage:   "<digest> [<label>=<value> ...]",
@@ -288,20 +287,20 @@ var (
 		},
 	}
 
-	editCommand = &cli.Command{
+	editCommand = cli.Command{
 		Name:        "edit",
 		Usage:       "Edit a blob and return a new digest",
 		ArgsUsage:   "[flags] <digest>",
 		Description: "edit a blob and return a new digest",
 		Flags: []cli.Flag{
-			&cli.StringFlag{
+			cli.StringFlag{
 				Name:  "validate",
 				Usage: "Validate the result against a format (json, mediatype, etc.)",
 			},
-			&cli.StringFlag{
-				Name:    "editor",
-				Usage:   "Select editor (vim, emacs, etc.)",
-				EnvVars: []string{"EDITOR"},
+			cli.StringFlag{
+				Name:   "editor",
+				Usage:  "Select editor (vim, emacs, etc.)",
+				EnvVar: "EDITOR",
 			},
 		},
 		Action: func(context *cli.Context) error {
@@ -357,7 +356,7 @@ var (
 		},
 	}
 
-	deleteCommand = &cli.Command{
+	deleteCommand = cli.Command{
 		Name:      "delete",
 		Aliases:   []string{"del", "remove", "rm"},
 		Usage:     "Permanently delete one or more blobs",
@@ -366,7 +365,7 @@ var (
 	blobs are printed to stdout.`,
 		Action: func(context *cli.Context) error {
 			var (
-				args      = context.Args().Slice()
+				args      = []string(context.Args())
 				exitError error
 			)
 			client, ctx, cancel, err := commands.NewClient(context)
@@ -406,7 +405,7 @@ var (
 	// TODO(stevvooe): Create "multi-fetch" mode that just takes a remote
 	// then receives object/hint lines on stdin, returning content as
 	// needed.
-	fetchObjectCommand = &cli.Command{
+	fetchObjectCommand = cli.Command{
 		Name:        "fetch-object",
 		Usage:       "Retrieve objects from a remote",
 		ArgsUsage:   "[flags] <remote> <object> [<hint>, ...]",
@@ -448,17 +447,12 @@ var (
 		},
 	}
 
-	fetchBlobCommand = &cli.Command{
+	fetchBlobCommand = cli.Command{
 		Name:        "fetch-blob",
 		Usage:       "Retrieve blobs from a remote",
 		ArgsUsage:   "[flags] <remote> [<digest>, ...]",
 		Description: `Fetch blobs by digests from a remote.`,
-		Flags: append(commands.RegistryFlags, []cli.Flag{
-			&cli.StringFlag{
-				Name:  "media-type",
-				Usage: "Specify target mediatype for request header",
-			},
-		}...),
+		Flags:       commands.RegistryFlags,
 		Action: func(context *cli.Context) error {
 			var (
 				ref     = context.Args().First()
@@ -493,11 +487,10 @@ var (
 				if err != nil {
 					return err
 				}
-				rc, desc, err := fetcherByDigest.FetchByDigest(ctx, dgst, remotes.WithMediaType(context.String("media-type")))
+				rc, _, err := fetcherByDigest.FetchByDigest(ctx, dgst)
 				if err != nil {
 					return err
 				}
-				log.G(ctx).Debugf("desc=%+v", desc)
 				_, err = io.Copy(os.Stdout, rc)
 				rc.Close()
 				if err != nil {
@@ -508,7 +501,7 @@ var (
 		},
 	}
 
-	pushObjectCommand = &cli.Command{
+	pushObjectCommand = cli.Command{
 		Name:        "push-object",
 		Usage:       "Push an object to a remote",
 		ArgsUsage:   "[flags] <remote> <object> <type>",
@@ -581,7 +574,7 @@ var (
 func edit(context *cli.Context, rd io.Reader) (_ io.ReadCloser, retErr error) {
 	editor := context.String("editor")
 	if editor == "" {
-		return nil, errors.New("editor is required")
+		return nil, fmt.Errorf("editor is required")
 	}
 
 	tmp, err := os.CreateTemp(os.Getenv("XDG_RUNTIME_DIR"), "edit-")
