@@ -19,28 +19,28 @@ package oci
 import (
 	"fmt"
 
-	"github.com/urfave/cli/v2"
+	"github.com/urfave/cli"
 
-	"github.com/containerd/containerd/v2/cmd/ctr/commands"
-	"github.com/containerd/containerd/v2/core/containers"
-	"github.com/containerd/containerd/v2/pkg/oci"
+	"github.com/containerd/containerd/cmd/ctr/commands"
+	"github.com/containerd/containerd/containers"
+	"github.com/containerd/containerd/oci"
 	"github.com/containerd/platforms"
 )
 
 // Command is the parent for all OCI related tools under 'oci'
-var Command = &cli.Command{
+var Command = cli.Command{
 	Name:  "oci",
 	Usage: "OCI tools",
-	Subcommands: []*cli.Command{
+	Subcommands: []cli.Command{
 		defaultSpecCommand,
 	},
 }
 
-var defaultSpecCommand = &cli.Command{
+var defaultSpecCommand = cli.Command{
 	Name:  "spec",
 	Usage: "See the output of the default OCI spec",
 	Flags: []cli.Flag{
-		&cli.StringFlag{
+		cli.StringFlag{
 			Name:  "platform",
 			Usage: "Platform of the spec to print (Examples: 'linux/arm64', 'windows/amd64')",
 		},
@@ -49,7 +49,7 @@ var defaultSpecCommand = &cli.Command{
 		ctx, cancel := commands.AppContext(context)
 		defer cancel()
 
-		platform := platforms.DefaultString()
+		platform := platforms.Format(platforms.DefaultSpec()) // For 1.7 continue using the old format without os-version included.
 		if plat := context.String("platform"); plat != "" {
 			platform = plat
 		}
