@@ -37,17 +37,13 @@ compile_fuzzers() {
     done
 }
 
-# This is from https://github.com/AdamKorcz/instrumentation
-cd $SRC/instrumentation
-go run main.go --target_dir $SRC/containerd/images
-
 apt-get update && apt-get install -y wget
 cd $SRC
-wget --quiet https://go.dev/dl/go1.23.7.linux-amd64.tar.gz
+wget --quiet https://go.dev/dl/go1.23.11.linux-amd64.tar.gz
 
 mkdir temp-go
 rm -rf /root/.go/*
-tar -C temp-go/ -xzf go1.23.7.linux-amd64.tar.gz
+tar -C temp-go/ -xzf go1.23.11.linux-amd64.tar.gz
 mv temp-go/go/* /root/.go/
 cd $SRC/containerd
 
