@@ -25,19 +25,19 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/container-orchestrated-devices/container-device-interface/pkg/cdi"
 	"github.com/containerd/containerd/containers"
 	"github.com/containerd/containerd/contrib/apparmor"
 	"github.com/containerd/containerd/contrib/seccomp"
 	"github.com/containerd/containerd/mount"
 	"github.com/containerd/containerd/oci"
-	"github.com/containerd/containerd/platforms"
+	"github.com/containerd/platforms"
 	imagespec "github.com/opencontainers/image-spec/specs-go/v1"
 	runtimespec "github.com/opencontainers/runtime-spec/specs-go"
 	"github.com/opencontainers/selinux/go-selinux"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	runtime "k8s.io/cri-api/pkg/apis/runtime/v1"
+	"tags.cncf.io/container-device-interface/pkg/cdi"
 
 	"github.com/containerd/containerd/pkg/cap"
 	"github.com/containerd/containerd/pkg/cri/annotations"
@@ -1929,8 +1929,7 @@ containerEdits:
 			}
 			require.NoError(t, err)
 
-			reg := cdi.GetRegistry()
-			err = reg.Configure(cdi.WithSpecDirs(cdiDir))
+			err = cdi.Configure(cdi.WithSpecDirs(cdiDir))
 			require.NoError(t, err)
 
 			injectFun := customopts.WithCDI(test.annotations, test.cdiDevices)
