@@ -26,7 +26,6 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/container-orchestrated-devices/container-device-interface/pkg/cdi"
 	"github.com/containerd/containerd/containers"
 	"github.com/containerd/containerd/contrib/apparmor"
 	"github.com/containerd/containerd/contrib/seccomp"
@@ -38,6 +37,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	runtime "k8s.io/cri-api/pkg/apis/runtime/v1"
+	"tags.cncf.io/container-device-interface/pkg/cdi"
 
 	"github.com/containerd/containerd/pkg/cap"
 	"github.com/containerd/containerd/pkg/cri/annotations"
@@ -2108,8 +2108,7 @@ containerEdits:
 			}
 			require.NoError(t, err)
 
-			reg := cdi.GetRegistry()
-			err = reg.Configure(cdi.WithSpecDirs(cdiDir))
+			err = cdi.Configure(cdi.WithSpecDirs(cdiDir))
 			require.NoError(t, err)
 
 			injectFun := customopts.WithCDI(test.annotations, test.cdiDevices)
