@@ -27,8 +27,8 @@ import (
 	"time"
 
 	transferapi "github.com/containerd/containerd/api/types/transfer"
-	"github.com/containerd/containerd/log"
 	"github.com/containerd/containerd/pkg/streaming"
+	"github.com/containerd/log"
 	"github.com/containerd/typeurl/v2"
 )
 
